@@ -18,7 +18,7 @@ extract_carbon_calibration_data <- function(data_list) {
   
   # extract desired data from data list.
   data <- data_list %>% 
-    dplyr::select(.data$verticalPosition, .data$timeBgn, .data$timeEnd,
+    dplyr::select("verticalPosition", "timeBgn", "timeEnd",
            tidyselect::starts_with("data.isoCo2.dlta13CCo2"),
            tidyselect::starts_with("data.isoCo2.rtioMoleDryCo2")) %>%
     dplyr::filter(.data$verticalPosition %in% c("co2High", "co2Med", "co2Low"))
