@@ -12,7 +12,7 @@
 #' @author Rich Fiorella \email{rfiorella@@lanl.gov}
 #'
 #' @export
-#' @examples 
+#' @examples
 #' terrestrial_core_sites()
 terrestrial_core_sites <- function() {
 
@@ -31,9 +31,9 @@ terrestrial_core_sites <- function() {
 #' @return A vector listing NEON core terrestrial sites.
 #'
 #' @author Rich Fiorella \email{rfiorella@@lanl.gov}
-#' 
+#'
 #' @export
-#' @examples 
+#' @examples
 #' terrestrial_relocatable_sites()
 
 terrestrial_relocatable_sites <- function() {
@@ -55,7 +55,10 @@ terrestrial_relocatable_sites <- function() {
 #' @return A vector listing NEON sites measuring water vapor isotope ratios.
 #'
 #' @author Rich Fiorella \email{rfiorella@@lanl.gov}
-#' 
+#'
+#' @export
+#' @examples
+#' water_isotope_sites()
 
 water_isotope_sites <- function() {
 
@@ -71,9 +74,9 @@ water_isotope_sites <- function() {
 }
 
 #' manage_local_EC_archive
-#' 
+#'
 #' Utility function to help retrieve new EC data and/or prune duplicates,
-#' as NEON provisions new data or re-provisions data for an existing site 
+#' as NEON provisions new data or re-provisions data for an existing site
 #' and month.
 #'
 #' @author Rich Fiorella \email{rfiorella@@lanl.gov}
@@ -82,20 +85,20 @@ water_isotope_sites <- function() {
 #' @param get Pull down data from NEON API that does not exist locally?
 #' @param unzip_files NEON gzips the hdf5 files, should we unzip any gzipped
 #'             files within file_dir? (Searches recursively)
-#' @param trim Search through local holdings, and remove older file where 
+#' @param trim Search through local holdings, and remove older file where
 #'             there are duplicates?
-#' @param dry_run List files identified as duplicates, but do not actually 
+#' @param dry_run List files identified as duplicates, but do not actually
 #'             delete them? Default true to prevent unintended data loss.
 #' @param sites Which sites to retrieve data from? Default will be all sites
 #'              with available data, but can specify a single site or a vector
-#'              here.           
+#'              here.
 #' @export
-#' 
-#' @return Returns nothing to the environment, but will download new NEON HDF5 files
-#'         for selected sites (if `get = TRUE`), unzip them in the local file directory
-#'         (if `unzip_files = TRUE`), and identify and remove suspected duplicate files
-#'         (if `trim = TRUE` and `dry_run = FALSE`).
-#' 
+#'
+#' @return Returns nothing to the environment, but will download new NEON HDF5
+#'         files for selected sites (if `get = TRUE`), unzip them in the local
+#'         file directory (if `unzip_files = TRUE`), and identify and remove
+#'         suspected duplicate files (if `trim = TRUE` and `dry_run = FALSE`).
+
 manage_local_EC_archive <- function(file_dir,
                                     get = TRUE,
                                     unzip_files = TRUE,
@@ -104,27 +107,27 @@ manage_local_EC_archive <- function(file_dir,
                                     sites = "all") {
 
   if (get == TRUE) {
-    
+
     # script to pull down EC data files.
     data_product <- "DP4.00200.001"
-    neon_api_address <- "http://data.neonscience.org/api/v0/products/"
-    
+    neon_api_address <- "https://data.neonscience.org/api/v0/products/"
+
     # make copy of site list available to this function
     csites <- terrestrial_core_sites()
     rsites <- terrestrial_relocatable_sites()
-    
+
     # see what sites have data
     data_request <- httr::GET(paste0(neon_api_address, data_product))
     # parse JSON object into an R list
     available <- httr::content(data_request, as = "parsed")
     # get number of sites.
     nsites <- length(available$data$siteCodes)
-    
+
     # loop through sites, and download data.
     for (i in 1:nsites) {
       # get site name
       site_name <- available$data$siteCodes[[i]]$siteCode
-      
+
       # check to see if site [i] is a core/relocatable site
       if (!(site_name %in% csites | site_name %in% rsites)) {
         print(paste("Site name", site_name,
@@ -141,43 +144,43 @@ manage_local_EC_archive <- function(file_dir,
       site_months <- unlist(available$data$siteCodes[[i]]$availableMonths)
 
       # okay, check to see if data folder exists for site, otherwise create.
-      ifelse(!dir.exists(paste(file_dir, site_name, sep="/")),
-             dir.create(paste(file_dir, site_name, sep="/")), FALSE)
-      
+      ifelse(!dir.exists(paste(file_dir, site_name, sep = "/")),
+             dir.create(paste(file_dir, site_name, sep = "/")), FALSE)
+
       # okay - now loop through months and get the data files.
       if (!is.null(length(site_months))) {
-        
+
         for (j in 1:length(site_months)) {
-          
+
           # re-query api w/ given site code and month.
           sitemonth_urls_json <- httr::GET(
             unlist(available$data$siteCodes[[i]]$availableDataUrls[j]))
-          
+
           # list files returned.
           sitemonth_urls_parsed <- httr::content(sitemonth_urls_json,
                                                  as = "parsed")
-          
+
           # extract just file names and URLs
           fnames <- sapply(sitemonth_urls_parsed$data$files, "[[", "name")
           furls  <- sapply(sitemonth_urls_parsed$data$files, "[[", "url")
-          
+
           # get basic zipfile for now, but should kick out to a
           # function argument later on.
           fnames_basic <- (grepl("basic", fnames) & grepl("h5.gz", fnames))
-          
+
           # check to see if files already exist, and download if missing.
           dl_names <- fnames[fnames_basic]
           dl_urls  <- furls[fnames_basic]
-          
+
           for (k in 1:length(dl_names)) {
-            if (!length(dl_names[k])==0) {
+            if (!length(dl_names[k]) == 0) {
               if (!is.na(dl_names[k])) {
                 # check to see if file exists in folder
                 if (file.exists(paste0(file_dir, site_name, "/", dl_names[k])) | # check for zipped or unzipped
-                    file.exists(paste0(file_dir, site_name, "/", 
-                                       substr(dl_names[k],1,nchar(dl_names[k])-3)))) {
+                    file.exists(paste0(file_dir, site_name, "/",
+                                       substr(dl_names[k], 1, nchar(dl_names[k]) - 3)))) {
                   print(paste(dl_names[k], "exists...skipping..."))
-                  next      
+                  next
                 } else { #doesn't exist, so download it.
                   print(paste("Downloading", dl_names[k]))
                   httr::GET(url = dl_urls[k],
@@ -186,10 +189,10 @@ manage_local_EC_archive <- function(file_dir,
                                                     "/",
                                                     dl_names[k]),
                                              overwrite = TRUE))
-                  
+
                 } # if
               }
-            }            
+            }
           } # k loop
         } # j loop
       } # if is.null
@@ -198,77 +201,74 @@ manage_local_EC_archive <- function(file_dir,
 
     } # i loop
   } # get branch.
-  
+
   # unzip files if requested.
   if (get == TRUE & unzip_files == TRUE) {
     # list the files in file_dir
-    files <- list.files(path = paste0(file_dir,"/"),
+    files <- list.files(path = paste0(file_dir, "/"),
                         pattern = "*.gz",
                         recursive = TRUE,
                         full.names = TRUE)
-    
+
     if (length(files) > 0) {
       lapply(files, function(x) {
-        #R.utils::gunzip(x, skip = TRUE, remove = FALSE)
         R.utils::gunzip(x)
       })
     }
   }
-  
+
   if (trim == TRUE) {
     # list the files in file_dir
     files <- list.files(path = file_dir,
                         pattern = "*.h5",
                         recursive = TRUE,
                         full.names = TRUE)
-    
+
     #need to extract sites, months from file names.
     file_pieces <- strsplit(files, split = ".", fixed = TRUE)
-    
-    #Unless there's a very unusual file path, the 
-    #site name should be element 3 of resulting list, 
+
+    #Unless there's a very unusual file path, the
+    #site name should be element 3 of resulting list,
     #and site year/month should be element 8. We'll
     #also want element 10, which is either 'h5' in the old
     #file naming convention, or is the publication date/time.
-    
+
     sites <- sapply(file_pieces, "[[", 3)
     yrmn  <- sapply(file_pieces, "[[", 8)
     fdiff <- sapply(file_pieces, "[[", 10)
-    
+
     site_list <- unique(sites)
-    
+
     for (i in seq_along(site_list)) {
       # get list of files where site == site[i]
       isite <- sites == site_list[i]
-      
+
       # check to see if there are duplicates of yrmn
       yrmn_isite <- yrmn[isite]
       fdiff_isite <- fdiff[isite]
       files_isite <- files[isite]
-      
+
       # test to see if there are any duplicates
       if (sum(duplicated(yrmn_isite) > 0)) {
-        
-        # get list of duplicated months
-        #print(paste(site_list[i],yrmn_isite[duplicated(yrmn_isite) | duplicated(yrmn_isite, fromLast = TRUE)]))
-        
+
         # print list of files that are duplicated?
         dups <- duplicated(yrmn_isite) | duplicated(yrmn_isite, fromLast = TRUE)
-        
+
         # narrow list to just list of candidate duplicate files.
         dup_candidates <- files_isite[dups]
         dup_yrmn       <- yrmn_isite[dups]
         dup_fdiff      <- fdiff_isite[dups]
-        
+
         # check to see if one site has an 'h5' fdiff and the duplicates
         # have a date.
-        if (!is.null(dup_candidates) & any(dup_fdiff == 'h5')) {
-          h5files <- fdiff_isite[dups] == 'h5'
-          print(paste('Removing:',dup_candidates[h5files]))
+        if (!is.null(dup_candidates) & any(dup_fdiff == "h5")) {
+          h5files <- fdiff_isite[dups] == "h5"
+          print(paste("Removing:", dup_candidates[h5files]))
           if (!dry_run) {
             file.remove(dup_candidates[h5files]) # remove files.
           }
-        } else { # none are simply h5, so need to determine which is the most recent file.
+        } else { # none are simply h5,
+                 # so need to determine which is the most recent file.
           for (i in 1:length(unique(dup_yrmn))) {
             # get times associated w/ particular duplicate.
             h5_times <- as.POSIXct(dup_fdiff[dup_yrmn == unique(dup_yrmn)[i]], format = "%Y%m%dT%H%M%SZ")
@@ -276,7 +276,7 @@ manage_local_EC_archive <- function(file_dir,
             # get file names for only this yrmn.
             dups_yrmn <- dup_candidates[(dup_yrmn == unique(dup_yrmn)[i]) & (h5_times != max(h5_times))]
             # print which files to remove
-            print(paste('Removing:',dups_yrmn))
+            print(paste("Removing:", dups_yrmn))
             if (!dry_run) {
               file.remove(dups_yrmn)
             }
@@ -284,10 +284,6 @@ manage_local_EC_archive <- function(file_dir,
         }
       }
     }
-  } 
-
-}
-
-
-
+  }
 
+}
\ No newline at end of file
